==> af_2.0.orig.tar.gz: af-2.0.orig/lib/strdup.c <==
/* Strdup.c - Duplicate an allocated string.
   Copyright (C) 1992, 1996 Malc Arnold.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */


#include <stdio.h>

/****************************************************************************/
/* RCS info. */

#ifndef lint
static char *RcsId = "$Id: strdup.c,v 2.0 1997/09/06 11:56:40 malc Rel $";
#endif /* ! lint */

/****************************************************************************/
/*LINTLIBRARY*/
/****************************************************************************/
/* Global function declarations */

extern char *malloc(), *strcpy();

/****************************************************************************/
char *strdup(s)
char *s;
{
	/* Return an allocated copy of a string */

	char *buf;

	if ((buf = malloc(strlen(s) + 1)) != NULL) {
		(void) strcpy(buf, s);
	}

	return(buf);
}
/****************************************************************************/

==> af_2.4.3.orig.tar.gz: af-2.4.3/lib/strdup.c <==
/* Strdup.c - Duplicate an allocated string.
   Copyright (C) 1992, 1996, 1997 Malc Arnold.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */


#include <stdio.h>

#ifdef HAVE_STRING_H
#include <string.h>
#else /* ! HAVE_STRING_H */
#include <strings.h>
#endif /* ! HAVE_STRING_H */

/****************************************************************************/
/* RCS info. */

#ifndef lint
static char *RcsId = "$Id: strdup.c,v 2.1 1997/09/07 00:35:35 malc Exp $";
#endif /* ! lint */

/****************************************************************************/
/*LINTLIBRARY*/
/****************************************************************************/
/* Global function declarations */

extern char *malloc(), *strcpy();

/****************************************************************************/
char *strdup(s)
char *s;
{
	/* Return an allocated copy of a string */

	char *buf;

	if ((buf = malloc(strlen(s) + 1)) != NULL) {
		(void) strcpy(buf, s);
	}

	return(buf);
}
/****************************************************************************/
